@@ -33,19 +33,22 @@ NULL
 #' * mergeReplicates: A function that combines replicated / repeated
 #'     measurements across all experiments and is guided by the replicated
 #'     return value
-#' * longFormat: A `MultiAssayExperiment` method that
-#'     returns a small and skinny [`DataFrame`]. The `colDataCols`
+#' * longForm: A `MultiAssayExperiment` method that returns a small and
+#'     skinny [`DataFrame`][S4Vectors::DataFrame-class]. The `colDataCols`
 #'     arguments allows the user to append `colData` columns to the data.
 #' * wideFormat: A function to reshape the data in a
-#'     `MultiAssayExperiment` to a "wide" format [`DataFrame`]. Each row in
-#'     the `DataFrame` represents an observation (corresponding to an entry in
-#'     the `colData`). If replicates are present, their data will be appended at
+#'     `MultiAssayExperiment` to a "wide" format
+#'     [`DataFrame`][S4Vectors::DataFrame-class]. Each row in the `DataFrame`
+#'     represents an observation (corresponding to an entry in the `colData`).
+#'     If replicates are present, their data will be appended at
 #'     the end of the corresponding row and will generate additional `NA` data.
 #'     It is recommended to remove or consolidate technical replicates with
 #'     `mergeReplicates`. Optional `colDataCols` can be added when the
 #'     original object is a `MultiAssayExperiment`.
 #' * hasRowRanges: A function that identifies ExperimentList elements
-#'     that have a [`rowRanges`][RangedSummarizedExperiment-class] method
+#'     that have a
+#'     [`rowRanges`][SummarizedExperiment::RangedSummarizedExperiment-class]
+#'     method
 #' * getWithColData: A convenience function for extracting an assay
 #'     and associated colData
 #' * renamePrimary: A convenience function to rename the primary
@@ -111,9 +114,9 @@ setGeneric("replicated", function(x) standardGeneric("replicated"))
 #' @rdname MultiAssayExperiment-helpers
 #'
 #' @details The `replicated` function finds replicate measurements in each
-#' assay and returns a list of [`LogicalList`]s.
-#' Each element in a single [`LogicalList`] corresponds to a
-#' biological or _primary_ unit as in the `sampleMap`. Below is a
+#' assay and returns a list of [`LogicalList`][IRanges::AtomicList]s.
+#' Each element in a single [`LogicalList`][IRanges::AtomicList] corresponds to
+#' a biological or _primary_ unit as in the `sampleMap`. Below is a
 #' small graphic for one particular biological unit in one assay, where the
 #' logical vector corresponds to the number of measurements/samples in the
 #' assay:
@@ -127,8 +130,8 @@ setGeneric("replicated", function(x) standardGeneric("replicated"))
 #' replicate. _Note_. These methods are not available for the
 #' `ExperimentList` class due to a missing `sampleMap` structure
 #' (by design).
-#' `showReplicated` returns a list of [`CharacterList`]s where
-#' each element corresponds to the the biological or _primary_ units that
+#' `showReplicated` returns a list of [`CharacterList`][IRanges::AtomicList]s
+#' where each element corresponds to the the biological or _primary_ units that
 #' are replicated in that assay element. The values in the inner list are
 #' the `colnames` in the assay that are technical replicates.
 #'
@@ -188,9 +191,9 @@ setGeneric("replicates", function(x, ...) standardGeneric("replicates"))
 #'
 #' @details The `replicates` function (noun) returns the `colname`s
 #'   from the `sampleMap` that were identified as replicates. It returns a
-#'   list of [`CharacterList`]s for each assay present in the
-#'   `MultiAssayExperiment` and an inner entry for each biological unit
-#'   that has replicate observations in that assay.
+#'   list of [`CharacterList`][IRanges::AtomicList]s for each assay present in
+#'   the `MultiAssayExperiment` and an inner entry for each biological unit that
+#'   has replicate observations in that assay.
 #'
 #' @export
 setMethod("replicates", "MultiAssayExperiment", function(x, ...) {
@@ -240,7 +243,7 @@ setGeneric("mergeReplicates",
 #' multiple measurements on the **same** sample (within the same assay)
 #' and can therefore be averaged.
 #'
-#' @param replicates A list of [`LogicalList`]s
+#' @param replicates A list of [`LogicalList`][IRanges::AtomicList]s
 #' indicating multiple / duplicate entries for each biological unit per assay,
 #' see `replicated` (default `replicated(x)`).
 #' @param simplify A function for merging repeat measurements in experiments
@@ -264,9 +267,9 @@ setMethod("mergeReplicates", "MultiAssayExperiment",
 #' @describeIn ExperimentList Apply the mergeReplicates method on the
 #' ExperimentList elements
 #'
-#' @param replicates mergeReplicates: A `list` or [`LogicalList`]
-#' where each element represents a sample and a vector of repeated measurements
-#' for the sample
+#' @param replicates mergeReplicates: A `list` or
+#'   [`LogicalList`][IRanges::AtomicList] where each element represents a
+#'   sample and a vector of repeated measurements for the sample
 #'
 #' @param simplify A function for merging columns where duplicates are indicated
 #' by replicates
@@ -336,38 +339,6 @@ setMethod("mergeReplicates", "ANY",
         return(object)
 })
 
-# longFormat function -----------------------------------------------------
-
-.longFormatANY <- function(object, i) {
-    rowNAMES <- rownames(object)
-    if (is.null(rowNAMES))
-        rowNames <- as.character(seq_len(nrow(object)))
-
-    if (is(object, "ExpressionSet"))
-        object <- Biobase::exprs(object)
-    if (is(object, "SummarizedExperiment") || is(object, "RaggedExperiment"))
-        object <- assay(object, i = i)
-
-    if (!requireNamespace("reshape2", quietly = TRUE))
-        stop("Package 'reshape2' is required for 'longFormat()' conversion")
-
-    reshape2::melt(
-        object, varnames = c("rowname", "colname"), value.name = "value"
-    )
-}
-
-.longFormatElist <- function(object, i) {
-    if (!is(object, "ExperimentList"))
-        stop("<internal> Not an 'ExperimentList' input")
-    samelength <- identical(length(object), length(i))
-    if (!samelength && identical(length(i), 1L))
-        i <- rep(i, length(object))
-    mapply(function(obj, obname, idx) {
-        data.frame(assay = obname, .longFormatANY(obj, i = idx),
-            stringsAsFactors = FALSE)
-        }, obj = object, obname = names(object), idx = i, SIMPLIFY = FALSE)
-}
-
 .matchAddColData <- function(reshaped, colData, colDataCols) {
     extraColumns <- as.data.frame(colData[, colDataCols, drop = FALSE])
     rowNameValues <- rownames(extraColumns)
@@ -387,16 +358,18 @@ setMethod("mergeReplicates", "ANY",
     reshaped[, c("assay", "primary", "rowname", "colname", "value")]
 }
 
+# longFrom method ---------------------------------------------------------
+
 #' @rdname MultiAssayExperiment-helpers
 #'
-#' @aliases longFormat
+#' @details The `longForm` "ANY" class method, works with classes such as
+#' [`ExpressionSet`][Biobase::ExpressionSet] and
+#' [`SummarizedExperiment`][SummarizedExperiment::SummarizedExperiment-class] as
+#' well as `matrix` to provide a consistent long and skinny
+#' [`DataFrame`][S4Vectors::DataFrame-class].
 #'
-#' @details The `longFormat` "ANY" class method, works with classes such as
-#' [`ExpressionSet`] and [`SummarizedExperiment`] as well as `matrix`
-#' to provide a consistent long and skinny [`DataFrame`].
-#'
-#' @section longFormat:
-#' The 'longFormat' method takes data from the [`ExperimentList`]
+#' @section longForm:
+#' The 'longForm' method takes data from the [`ExperimentList`]
 #' in a `MultiAssayExperiment` and returns a uniform
 #' `DataFrame`. The resulting DataFrame has columns indicating
 #' primary, rowname, colname and value. This method can optionally include
@@ -410,38 +383,79 @@ setMethod("mergeReplicates", "ANY",
 #' @param colDataCols A `character`, `logical`, or `numeric`
 #'     index for `colData` columns to be included
 #'
-#' @param i longFormat: The i-th assay in
+#' @param i longForm: The i-th assay in
 #'     `SummarizedExperiment`-like objects. A vector input is
 #'     supported in the case that the `SummarizedExperiment` object(s) has more
 #'     than one assay (default 1L),
 #'     renameColname: Either a `numeric` or `character` index
 #'     indicating the assay whose colnames are to be renamed
 #'
-#' @param mode String indicating how `MultiAssayExperiment`
-#'     column-level metadata should be added to the
-#'     `SummarizedExperiment` `colData`.
+#' @importFrom BiocBaseUtils lifeCycle
+#' @importFrom BiocGenerics longForm
 #'
-#' @export longFormat
-longFormat <- function(object, colDataCols = NULL, i = 1L) {
-    if (is(object, "ExperimentList"))
-        return(do.call(rbind, .longFormatElist(object, i = i)))
-    else if (!is(object, "MultiAssayExperiment"))
-        return(.longFormatANY(object, i = i))
+#' @exportMethod longForm
+setMethod(
+    "longForm", "MultiAssayExperiment",
+    function(object, colDataCols = NULL, i = 1L, ...) {
+        if (any(.emptyAssays(experiments(object))))
+            object <- .dropEmpty(object, warn = FALSE)
 
-    if (any(.emptyAssays(experiments(object))))
-        object <- .dropEmpty(object, warn = FALSE)
+        longDataFrame <- longForm(experiments(object), i = i)
 
-    longDataFrame <- do.call(function(...) rbind(..., make.row.names = FALSE),
-        .longFormatElist(experiments(object), i = i))
+        longDataFrame <- .mapOrderPrimary(longDataFrame, sampleMap(object))
 
-    longDataFrame <- .mapOrderPrimary(longDataFrame, sampleMap(object))
+        if (!is.null(colDataCols))
+            longDataFrame <-
+                .matchAddColData(longDataFrame, colData(object), colDataCols)
 
-    if (!is.null(colDataCols))
-        longDataFrame <-
-            .matchAddColData(longDataFrame, colData(object), colDataCols)
+        as(longDataFrame, "DataFrame")
+    }
+)
 
-    as(longDataFrame, "DataFrame")
-}
+#' @rdname MultiAssayExperiment-helpers
+#' @exportMethod longForm
+setMethod(
+    "longForm", "ExperimentList",
+    function(object, colDataCols, i = 1L, ...) {
+        samelength <- identical(length(object), length(i))
+        if (!samelength && identical(length(i), 1L))
+            i <- rep(i, length(object))
+        res <- mapply(
+            function(obj, obname, idx) {
+                data.frame(
+                    assay = obname,
+                    longForm(obj, i = idx),
+                    stringsAsFactors = FALSE
+                )
+            }, obj = object, obname = names(object), idx = i, SIMPLIFY = FALSE
+        )
+        do.call(
+            function(...) rbind(..., make.row.names = FALSE),
+            res
+        )
+    }
+)
+
+#' @rdname MultiAssayExperiment-helpers
+#' @exportMethod longForm
+setMethod("longForm", "ANY", function(object, colDataCols, i = 1L, ...) {
+    rowNAMES <- rownames(object)
+    if (is.null(rowNAMES)) rowNames <- as.character(seq_len(nrow(object)))
+
+    if (is(object, "ExpressionSet"))
+        object <- Biobase::exprs(object)
+    if (is(object, "SummarizedExperiment") || is(object, "RaggedExperiment"))
+        object <- assay(object, i = i)
+
+    BiocBaseUtils::checkInstalled("reshape2")
+
+    res <- reshape2::melt(
+        object, varnames = c("rowname", "colname"), value.name = "value"
+    )
+    if (!is.character(res[["rowname"]]))
+        res[["rowname"]] <- as.character(res[["rowname"]])
+    res
+})
 
 # wideformat function -----------------------------------------------------
 
@@ -527,7 +541,8 @@ wideFormat <- function(object, colDataCols = NULL, check.names = TRUE,
     if (is.null(colDataCols)) colDataCols <- character(0L)
     nameFUN <- if (check.names) make.names else I
     cnames <- colnames(object)
-    longList <- .longFormatElist(experiments(object), i = i)
+    longDataFrame <- longForm(experiments(object), i = i)
+    longList <- split(longDataFrame, longDataFrame[["assay"]])
     longList <- lapply(longList, .mapOrderPrimary, sampleMap(object))
     colsofinterest <- c("assay", "rowname")
 
@@ -599,7 +614,8 @@ wideFormat <- function(object, colDataCols = NULL, check.names = TRUE,
 #' @section hasRowRanges:
 #' The `hasRowRanges` method identifies assays with associated ranged
 #' row data by directly testing the method on the object. The result from the
-#' test must be a [`GRanges`] class object to satisfy the test.
+#' test must be a [`GRanges`][GenomicRanges::GRanges-class] class object to
+#' satisfy the test.
 #'
 #' @export hasRowRanges
 setGeneric("hasRowRanges", function(x) standardGeneric("hasRowRanges"))
@@ -607,8 +623,8 @@ setGeneric("hasRowRanges", function(x) standardGeneric("hasRowRanges"))
 #' @rdname MultiAssayExperiment-helpers
 #'
 #' @details The `hasRowRanges` method identifies assays that support
-#' a [`rowRanges`][RangedSummarizedExperiment-class] method _and_
-#' return a [`GRanges`] object.
+#' a [`rowRanges`][SummarizedExperiment::RangedSummarizedExperiment-class]
+#' method _and_ return a [`GRanges`][GenomicRanges::GRanges-class] object.
 setMethod("hasRowRanges", "MultiAssayExperiment", function(x) {
     hasRowRanges(experiments(x))
 })
@@ -621,6 +637,10 @@ setMethod("hasRowRanges", "ExperimentList", function(x) {
 
 #' @rdname MultiAssayExperiment-helpers
 #'
+#' @param mode String indicating how `MultiAssayExperiment`
+#'     column-level metadata should be added to the
+#'     `SummarizedExperiment` `colData`.
+#'
 #' @param verbose `logical(1)` Whether to `suppressMessages` on subsetting
 #'     operations in `getWithColData` (default FALSE)
 #'
@@ -633,7 +653,8 @@ setMethod("hasRowRanges", "ExperimentList", function(x) {
 #' [`colData`][SummarizedExperiment::SummarizedExperiment-class]
 #' along with the extracted object using the `colData<-` replacement
 #' method when possible. Typically, this method is available for
-#' [`SummarizedExperiment`] and `RaggedExperiment` classes.
+#' [`SummarizedExperiment`][SummarizedExperiment::SummarizedExperiment-class]
+#' and `RaggedExperiment` classes.
 #'
 #' The setting of `mode` determines how the `colData`
 #' is added. If `mode="append"`, the `MultiAssayExperiment`
@@ -748,7 +769,6 @@ renamePrimary <- function(x, value) {
 #' colnames(mae2)
 #' sampleMap(mae2)
 #'
-#'
 #' @export renameColname
 renameColname <- function(x, i, value) {
     stopifnot(length(i) == 1L, !is.na(i), !missing(i))
